.. documentation master file

************
Inequality
************

**inequality** implements measures for the analysis of inequality over space and time and is part of the  `PySAL family <https://pysal.org>`_

Details are available in the `inequality api <api.html>`_.

An Example: Spatial Inequality in Mexico: 1940-2000
============================================================

.. raw:: html

    <div class="container-fluid">
      <div class="row equal-height">
        <div class="col-sm-1 col-xs-hidden">
        </div>
        <div class="col-md-3 col-xs-12">
            <a href="https://nbviewer.org/github/pysal/inequality/blob/main/docs/user-guide/measure/theil.ipynb" class="thumbnail">
                <img src="_static/images/theil.png" class="img-responsive center-block">
                <div class="caption text-center">
                <h6>Spatial Inequality Decomposition (Theil)</h6>
                </div>
            </a>
        </div>
        <div class="col-sm-3 col-xs-12">
            <a href="http://nbviewer.org/github/pysal/inequality/blob/main/docs/user-guide/measure/theil.ipynb" class="thumbnail">
                <img src="_static/images/regions.png" class="img-responsive center-block">
                <div class="caption text-center">
                <h6>Regions</h6>
                </div>
            </a>
        </div>
        <div class="col-sm-3 col-xs-12">
            <a href="https://nbviewer.org/github/pysal/inequality/blob/main/docs/user-guide/viz/pengram.ipynb" class="thumbnail">
                <img src="_static/images/pen.png"
                class="img-responsive center-block">
                <div class="caption text-center">
                <h6>Pengram
                </h6>
                </div>
            </a>
        </div>
        <div class="col-sm-2 col-xs-hidden">
        </div>
      </div>
    </div>






Development
===========

The package is currently maintained by `@sjsrey`_



https://github.com/pysal/inequality

Getting Involved
======================

If you are interested in contributing to PySAL please see our
`development guidelines <http://pysal.readthedocs.org/en/latest/developers/index.html>`_.


Bug reports
===============

To search for or report bugs, please see inequality's issues_.

.. _issues :  http://github.com/pysal/inequality/issues


Citing inequality
==================

If you use PySAL-inequality in a scientific publication, we would appreciate citations to:


Sergio Rey, James Gaboardi, Wei Kang, Philip Stephens, Renan Xavier Cortes, Dani Arribas-Bel, Levi John Wolf, & Martin Fleischmann. (2023). pysal/inequality: v1.0.1 (v1.0.1). Zenodo. https://doi.org/10.5281/zenodo.10050549

Bibtex entry::
  
     @software{inequality-devs2023,
       author       = {Sergio Rey and
                       James Gaboardi and
                       Wei Kang and
                       Philip Stephens and
                       Renan Xavier Cortes and
                       Dani Arribas-Bel and
                       Levi John Wolf and
                       Martin Fleischmann},
       title        = {pysal/inequality: v1.0.1},
       month        = oct,
       year         = 2023,
       publisher    = {Zenodo},
       version      = {v1.0.1},
       doi          = {10.5281/zenodo.10050549},
       url          = {https://doi.org/10.5281/zenodo.10050549},
     }





License information
========================

See the file "LICENSE.txt" for information on the history of this
software, terms & conditions for usage, and a DISCLAIMER OF ALL
WARRANTIES.


inequality
==========

Documentation contents
----------------------

.. toctree::
   :maxdepth: 1

   Home <self>
   Installation <installation>
   API reference <api>
   user-guide/intro
   References <references>
   
.. _PySAL: https://github.com/pysal/pysal
.. _PySAL (Python Spatial Analysis Library): http://pysal.org
.. _GeoPandas: http://geopandas.org
.. _PySAL: http://pysal.org
.. _@sjsrey: http://github.org/sjsrey
.. _issue: https://github.com/pysal/inequality/issues/new/choose
.. _discussion: https://github.com/pysal/inequality/discussions
.. _Discord: https://discord.com/channels/1192517762103398401/1192517763986632766
